# PyDriver Package

## Module for Speaker Management

### Methods
#### get_volume: Returns the current volume of the device's speakers
#### set_volume: Sets the volume of the device's speakers to the given volume level.
#### rangify: Interpolates or maps the given volume range of the speakers to the user-specified range.